#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_BITOFSIGN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_BITOFSIGN_HPP_INCLUDED

#include <nt2/ieee/include/functions/scalar/bitofsign.hpp>

#endif
